@@ -131,7 +131,7 @@ struct _EogWrapListPrivate {
 };
 
 static void eog_wrap_list_class_init (EogWrapListClass *class);
-static void eog_wrap_list_instance_init (EogWrapList *wlist);
+static void eog_wrap_list_init (EogWrapList *wlist);
 static void eog_wrap_list_dispose (GObject *object);
 static void eog_wrap_list_finalize (GObject *object);
 
@@ -146,11 +146,9 @@ static void eog_wrap_list_drag_data_get_cb (GtkWidget *widget,
 static void request_update (EogWrapList *wlist);
 static gboolean do_update (EogWrapList *wlist);
 static gint handle_canvas_click (GnomeCanvas *canvas, GdkEventButton *event, gpointer data);
+static gboolean handle_canvas_scroll (GnomeCanvas *canvas, GdkEventScroll *event, gpointer data);
 
-GNOME_CLASS_BOILERPLATE (EogWrapList,
-			 eog_wrap_list,
-			 GnomeCanvas,
-			 GNOME_TYPE_CANVAS)
+G_DEFINE_TYPE (EogWrapList, eog_wrap_list, GNOME_TYPE_CANVAS)
 
 /* Class initialization function for the abstract wrapped list view */
 static void
@@ -206,7 +204,7 @@ eog_wrap_list_class_init (EogWrapListClass *class)
 
 /* object initialization function for the abstract wrapped list view */
 static void
-eog_wrap_list_instance_init (EogWrapList *wlist)
+eog_wrap_list_init (EogWrapList *wlist)
 {
 	EogWrapListPrivate *priv;
 
@@ -254,7 +252,7 @@ eog_wrap_list_dispose (GObject *object)
 
 	/* FIXME: free the items and item array */
 	
-	GNOME_CALL_PARENT (G_OBJECT_CLASS, dispose, (object));
+	G_OBJECT_CLASS (eog_wrap_list_parent_class)->dispose (object);
 }
 
 static void
@@ -270,8 +268,8 @@ eog_wrap_list_finalize (GObject *object)
 		g_free (wlist->priv);
 	wlist->priv = NULL;
 
-	if (G_OBJECT_CLASS (parent_class)->finalize)
-		(* G_OBJECT_CLASS (parent_class)->finalize) (object);
+	if (G_OBJECT_CLASS (eog_wrap_list_parent_class)->finalize)
+		(* G_OBJECT_CLASS (eog_wrap_list_parent_class)->finalize) (object);
 }
 
 static void
@@ -284,6 +282,11 @@ eog_wrap_list_construct (EogWrapList *wlist)
 				"button-press-event",
 				G_CALLBACK (handle_canvas_click),
 				wlist);
+
+	g_signal_connect_after (G_OBJECT (wlist), 
+			  	"scroll_event",
+			  	G_CALLBACK (handle_canvas_scroll),
+			  	wlist);
 }
 
 
@@ -419,6 +422,47 @@ deselect_all (EogWrapList *wlist)
 	}
 }
 
+static gboolean
+handle_canvas_scroll (GnomeCanvas *canvas, GdkEventScroll *event, gpointer data)
+{
+	EogWrapList *wlist;
+	EogWrapListPrivate *priv;
+
+	g_return_val_if_fail (data != NULL, FALSE);
+	g_return_val_if_fail (EOG_IS_WRAP_LIST (data), FALSE);
+
+	wlist = EOG_WRAP_LIST (data);
+	priv = wlist->priv;
+
+	switch (event->direction) {
+	case GDK_SCROLL_UP:
+		eog_wrap_list_select_single (EOG_WRAP_LIST (wlist), 
+					     EOG_WRAP_LIST_SELECT_LEFT);
+		break;
+
+	case GDK_SCROLL_LEFT:
+		eog_wrap_list_select_single (EOG_WRAP_LIST (wlist), 
+					     EOG_WRAP_LIST_SELECT_LEFT);
+		break;
+
+	case GDK_SCROLL_DOWN:
+		eog_wrap_list_select_single (EOG_WRAP_LIST (wlist), 
+					     EOG_WRAP_LIST_SELECT_RIGHT);
+		break;
+
+	case GDK_SCROLL_RIGHT:
+		eog_wrap_list_select_single (EOG_WRAP_LIST (wlist), 
+					     EOG_WRAP_LIST_SELECT_RIGHT);
+		break;
+
+	default:
+		g_assert_not_reached ();
+		return FALSE;
+	}
+
+	return TRUE;
+}
+
 static gint
 handle_canvas_click (GnomeCanvas *canvas, GdkEventButton *event, gpointer data)
 {
@@ -590,7 +634,8 @@ eog_wrap_list_size_allocate (GtkWidget *widget, GtkAllocation *allocation)
 	wlist = EOG_WRAP_LIST (widget);
 	priv = wlist->priv;
 
-	GNOME_CALL_PARENT (GTK_WIDGET_CLASS, size_allocate, (widget, allocation));
+	GTK_WIDGET_CLASS (eog_wrap_list_parent_class)->size_allocate (widget,
+								    allocation);
 
 	priv->global_update_hints[GLOBAL_WIDGET_SIZE_CHANGED] = TRUE;
 
@@ -689,7 +734,12 @@ eog_wrap_list_key_press_cb (GtkWidget *widget, GdkEventKey *event)
 	};
 
 	if (!handled) 
-		handled = GNOME_CALL_PARENT_WITH_DEFAULT (GTK_WIDGET_CLASS, key_press_event, (widget, event), FALSE);
+	{
+		if (GTK_WIDGET_CLASS (eog_wrap_list_parent_class)->key_press_event)
+			handled = GTK_WIDGET_CLASS (eog_wrap_list_parent_class)->key_press_event (widget, event);
+		else
+			handled = FALSE;
+	}
 
 	return handled;
 }
